@@ -1,5 +1,7 @@
 var NAVTREEINDEX10 =
 {
+"group__API__SC__Hypervisor.html#gaafac498199c6441e2d45c9b4eac8dfe4":[57,46,7],
+"group__API__SC__Hypervisor.html#gab02cf89fff4e322e47bc96fb3b60b1ac":[57,46,44],
 "group__API__SC__Hypervisor.html#gab4e7dd4e4841b9e3db584b903043c3ad":[57,46,41],
 "group__API__SC__Hypervisor.html#gab5a609dbc1fe1703ff8b3d10410f7cc8":[57,46,22],
 "group__API__SC__Hypervisor.html#gabcccdef713031ad99b58c302af45fe99":[57,46,32],
@@ -247,7 +249,5 @@ var NAVTREEINDEX10 =
 "group__API__Task__Lists.html#af66edbac990d8e894796ca5d5dd45138":[57,8,0,0],
 "group__API__Task__Lists.html#ga02a847856d87dc7027c6f57e22a9e481":[57,8,12],
 "group__API__Task__Lists.html#ga1a9fbeedd7b9b0f77a18a8754a1bdeab":[57,8,13],
-"group__API__Task__Lists.html#ga367d90424e132d762e9a11eac2a822af":[57,8,10],
-"group__API__Task__Lists.html#ga37f7421eb2dcf9d808220db8454f0fac":[57,8,11],
-"group__API__Task__Lists.html#ga5618612b0ce2f914ab9032474ddf072f":[57,8,1]
+"group__API__Task__Lists.html#ga367d90424e132d762e9a11eac2a822af":[57,8,10]
 };
