@@ -1,38 +1,39 @@
 var NAVTREEINDEX12 =
 {
 "interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[58,0,0,6],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__block__shadow.html":[59,0,0,7],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[59,0,0,6],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__block__shadow.html":[58,0,0,7],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block.html":[59,0,0,8],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__block__shadow.html":[59,0,0,7],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block.html":[58,0,0,8],
-"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block__shadow.html":[59,0,0,9],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block.html":[59,0,0,8],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block__shadow.html":[58,0,0,9],
+"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block__shadow.html":[59,0,0,9],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block.html":[58,0,0,10],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block.html":[59,0,0,10],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block__shadow.html":[58,0,0,11],
 "interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block__shadow.html":[59,0,0,11],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ldy.html":[58,0,0,12],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ldy.html":[59,0,0,12],
-"interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html":[58,0,0,13],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html":[59,0,0,13],
-"interfacefstarpu__mod_1_1fstarpu__block__get__nx.html":[58,0,0,14],
+"interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html":[58,0,0,13],
 "interfacefstarpu__mod_1_1fstarpu__block__get__nx.html":[59,0,0,14],
-"interfacefstarpu__mod_1_1fstarpu__block__get__ny.html":[58,0,0,15],
+"interfacefstarpu__mod_1_1fstarpu__block__get__nx.html":[58,0,0,14],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ny.html":[59,0,0,15],
+"interfacefstarpu__mod_1_1fstarpu__block__get__ny.html":[58,0,0,15],
 "interfacefstarpu__mod_1_1fstarpu__block__get__nz.html":[58,0,0,16],
 "interfacefstarpu__mod_1_1fstarpu__block__get__nz.html":[59,0,0,16],
-"interfacefstarpu__mod_1_1fstarpu__block__get__ptr.html":[58,0,0,17],
 "interfacefstarpu__mod_1_1fstarpu__block__get__ptr.html":[59,0,0,17],
+"interfacefstarpu__mod_1_1fstarpu__block__get__ptr.html":[58,0,0,17],
 "interfacefstarpu__mod_1_1fstarpu__block__ptr__register.html":[59,0,0,18],
 "interfacefstarpu__mod_1_1fstarpu__block__ptr__register.html":[58,0,0,18],
-"interfacefstarpu__mod_1_1fstarpu__codelet__add__buffer.html":[58,0,0,19],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__buffer.html":[59,0,0,19],
+"interfacefstarpu__mod_1_1fstarpu__codelet__add__buffer.html":[58,0,0,19],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cpu__func.html":[59,0,0,20],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cpu__func.html":[58,0,0,20],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html":[59,0,0,21],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html":[58,0,0,21],
-"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__func.html":[58,0,0,22],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__func.html":[59,0,0,22],
+"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__func.html":[58,0,0,22],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__flags.html":[59,0,0,23],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__flags.html":[58,0,0,23],
 "interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__func.html":[59,0,0,24],
@@ -43,54 +44,54 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__codelet__display__stats.html":[58,0,0,26],
 "interfacefstarpu__mod_1_1fstarpu__codelet__free.html":[58,0,0,27],
 "interfacefstarpu__mod_1_1fstarpu__codelet__free.html":[59,0,0,27],
-"interfacefstarpu__mod_1_1fstarpu__codelet__init.html":[59,0,0,28],
 "interfacefstarpu__mod_1_1fstarpu__codelet__init.html":[58,0,0,28],
+"interfacefstarpu__mod_1_1fstarpu__codelet__init.html":[59,0,0,28],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__color.html":[58,0,0,29],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__color.html":[59,0,0,29],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[59,0,0,30],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[58,0,0,30],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[59,0,0,30],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[59,0,0,31],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[58,0,0,31],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html":[59,0,0,32],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html":[58,0,0,32],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html":[59,0,0,32],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__model.html":[59,0,0,33],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__model.html":[58,0,0,33],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html":[59,0,0,34],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html":[58,0,0,34],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__nbuffers.html":[59,0,0,35],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__nbuffers.html":[58,0,0,35],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__type.html":[59,0,0,36],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__type.html":[58,0,0,36],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__type.html":[59,0,0,36],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__variable__nbuffers.html":[58,0,0,37],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__variable__nbuffers.html":[59,0,0,37],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__where.html":[59,0,0,38],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__where.html":[58,0,0,38],
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__where.html":[59,0,0,38],
 "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__count.html":[58,0,0,39],
 "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__count.html":[59,0,0,39],
-"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__id.html":[59,0,0,40],
 "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__id.html":[58,0,0,40],
-"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__rank.html":[59,0,0,41],
+"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__id.html":[59,0,0,40],
 "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__rank.html":[58,0,0,41],
-"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__size.html":[58,0,0,42],
+"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__rank.html":[59,0,0,41],
 "interfacefstarpu__mod_1_1fstarpu__combined__worker__get__size.html":[59,0,0,42],
-"interfacefstarpu__mod_1_1fstarpu__conf__allocate.html":[59,0,0,43],
+"interfacefstarpu__mod_1_1fstarpu__combined__worker__get__size.html":[58,0,0,42],
 "interfacefstarpu__mod_1_1fstarpu__conf__allocate.html":[58,0,0,43],
+"interfacefstarpu__mod_1_1fstarpu__conf__allocate.html":[59,0,0,43],
 "interfacefstarpu__mod_1_1fstarpu__conf__free.html":[59,0,0,44],
 "interfacefstarpu__mod_1_1fstarpu__conf__free.html":[58,0,0,44],
-"interfacefstarpu__mod_1_1fstarpu__conf__init.html":[58,0,0,45],
 "interfacefstarpu__mod_1_1fstarpu__conf__init.html":[59,0,0,45],
-"interfacefstarpu__mod_1_1fstarpu__conf__set__max__prio.html":[58,0,0,46],
+"interfacefstarpu__mod_1_1fstarpu__conf__init.html":[58,0,0,45],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__max__prio.html":[59,0,0,46],
-"interfacefstarpu__mod_1_1fstarpu__conf__set__min__prio.html":[58,0,0,47],
+"interfacefstarpu__mod_1_1fstarpu__conf__set__max__prio.html":[58,0,0,46],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__min__prio.html":[59,0,0,47],
-"interfacefstarpu__mod_1_1fstarpu__conf__set__ncpu.html":[58,0,0,48],
+"interfacefstarpu__mod_1_1fstarpu__conf__set__min__prio.html":[58,0,0,47],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__ncpu.html":[59,0,0,48],
-"interfacefstarpu__mod_1_1fstarpu__conf__set__ncuda.html":[58,0,0,49],
+"interfacefstarpu__mod_1_1fstarpu__conf__set__ncpu.html":[58,0,0,48],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__ncuda.html":[59,0,0,49],
+"interfacefstarpu__mod_1_1fstarpu__conf__set__ncuda.html":[58,0,0,49],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__nopencl.html":[58,0,0,50],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__nopencl.html":[59,0,0,50],
-"interfacefstarpu__mod_1_1fstarpu__conf__set__sched__policy__name.html":[58,0,0,51],
 "interfacefstarpu__mod_1_1fstarpu__conf__set__sched__policy__name.html":[59,0,0,51],
+"interfacefstarpu__mod_1_1fstarpu__conf__set__sched__policy__name.html":[58,0,0,51],
 "interfacefstarpu__mod_1_1fstarpu__cpu__worker__get__count.html":[58,0,0,52],
 "interfacefstarpu__mod_1_1fstarpu__cpu__worker__get__count.html":[59,0,0,52],
 "interfacefstarpu__mod_1_1fstarpu__create__sync__task.html":[58,0,0,53],
@@ -103,32 +104,32 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__cuda__get__local__stream.html":[59,0,0,56],
 "interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[58,0,0,57],
 "interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[59,0,0,57],
-"interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[58,0,0,58],
 "interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[59,0,0,58],
-"interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[58,0,0,59],
+"interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[58,0,0,58],
 "interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[59,0,0,59],
-"interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[58,0,0,60],
+"interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[58,0,0,59],
 "interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[59,0,0,60],
-"interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[58,0,0,61],
+"interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[58,0,0,60],
 "interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[59,0,0,61],
-"interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[58,0,0,62],
+"interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[58,0,0,61],
 "interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[59,0,0,62],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[58,0,0,63],
+"interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[58,0,0,62],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[59,0,0,63],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[58,0,0,64],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[58,0,0,63],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[59,0,0,64],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[58,0,0,65],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[58,0,0,64],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[59,0,0,65],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[58,0,0,65],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[59,0,0,66],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[58,0,0,66],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[58,0,0,67],
 "interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[59,0,0,67],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[58,0,0,67],
 "interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[58,0,0,68],
 "interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[59,0,0,68],
 "interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[58,0,0,69],
 "interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[59,0,0,69],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[59,0,0,70],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[58,0,0,70],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[59,0,0,70],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[58,0,0,71],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[59,0,0,71],
 "interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[58,0,0,72],
@@ -147,18 +148,18 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[58,0,0,78],
 "interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[59,0,0,79],
 "interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[58,0,0,79],
-"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[59,0,0,80],
 "interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[58,0,0,80],
-"interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[59,0,0,81],
+"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[59,0,0,80],
 "interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[58,0,0,81],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[59,0,0,82],
+"interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[59,0,0,81],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[58,0,0,82],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[59,0,0,83],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[59,0,0,82],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[58,0,0,83],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[59,0,0,83],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[58,0,0,84],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[59,0,0,84],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[59,0,0,85],
 "interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[58,0,0,85],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[59,0,0,85],
 "interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[59,0,0,86],
 "interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[58,0,0,86],
 "interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[59,0,0,87],
@@ -171,83 +172,82 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[58,0,0,90],
 "interfacefstarpu__mod_1_1fstarpu__data__map__filters.html":[59,0,0,91],
 "interfacefstarpu__mod_1_1fstarpu__data__map__filters.html":[58,0,0,91],
-"interfacefstarpu__mod_1_1fstarpu__data__partition.html":[58,0,0,92],
 "interfacefstarpu__mod_1_1fstarpu__data__partition.html":[59,0,0,92],
+"interfacefstarpu__mod_1_1fstarpu__data__partition.html":[58,0,0,92],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[59,0,0,93],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[58,0,0,93],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[58,0,0,94],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[59,0,0,94],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html":[58,0,0,95],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[58,0,0,94],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html":[59,0,0,95],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[59,0,0,96],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html":[58,0,0,95],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[58,0,0,96],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[59,0,0,97],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[59,0,0,96],
 "interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[58,0,0,97],
-"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[59,0,0,98],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[59,0,0,97],
 "interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[58,0,0,98],
+"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[59,0,0,98],
 "interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html":[58,0,0,99],
 "interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html":[59,0,0,99],
 "interfacefstarpu__mod_1_1fstarpu__data__register__same.html":[58,0,0,100],
 "interfacefstarpu__mod_1_1fstarpu__data__register__same.html":[59,0,0,100],
 "interfacefstarpu__mod_1_1fstarpu__data__release.html":[58,0,0,101],
 "interfacefstarpu__mod_1_1fstarpu__data__release.html":[59,0,0,101],
-"interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html":[59,0,0,102],
 "interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html":[58,0,0,102],
-"interfacefstarpu__mod_1_1fstarpu__data__request__allocation.html":[58,0,0,103],
+"interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html":[59,0,0,102],
 "interfacefstarpu__mod_1_1fstarpu__data__request__allocation.html":[59,0,0,103],
-"interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods.html":[58,0,0,104],
+"interfacefstarpu__mod_1_1fstarpu__data__request__allocation.html":[58,0,0,103],
 "interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods.html":[59,0,0,104],
-"interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods__with__args.html":[58,0,0,105],
+"interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods.html":[58,0,0,104],
 "interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods__with__args.html":[59,0,0,105],
-"interfacefstarpu__mod_1_1fstarpu__data__test__if__allocated__on__node.html":[58,0,0,106],
+"interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods__with__args.html":[58,0,0,105],
 "interfacefstarpu__mod_1_1fstarpu__data__test__if__allocated__on__node.html":[59,0,0,106],
+"interfacefstarpu__mod_1_1fstarpu__data__test__if__allocated__on__node.html":[58,0,0,106],
 "interfacefstarpu__mod_1_1fstarpu__data__unpartition.html":[58,0,0,107],
 "interfacefstarpu__mod_1_1fstarpu__data__unpartition.html":[59,0,0,107],
-"interfacefstarpu__mod_1_1fstarpu__data__unpartition__readonly__submit.html":[59,0,0,108],
 "interfacefstarpu__mod_1_1fstarpu__data__unpartition__readonly__submit.html":[58,0,0,108],
+"interfacefstarpu__mod_1_1fstarpu__data__unpartition__readonly__submit.html":[59,0,0,108],
 "interfacefstarpu__mod_1_1fstarpu__data__unpartition__submit.html":[59,0,0,109],
 "interfacefstarpu__mod_1_1fstarpu__data__unpartition__submit.html":[58,0,0,109],
-"interfacefstarpu__mod_1_1fstarpu__data__unregister.html":[59,0,0,110],
 "interfacefstarpu__mod_1_1fstarpu__data__unregister.html":[58,0,0,110],
+"interfacefstarpu__mod_1_1fstarpu__data__unregister.html":[59,0,0,110],
 "interfacefstarpu__mod_1_1fstarpu__data__unregister__no__coherency.html":[59,0,0,111],
 "interfacefstarpu__mod_1_1fstarpu__data__unregister__no__coherency.html":[58,0,0,111],
-"interfacefstarpu__mod_1_1fstarpu__data__unregister__submit.html":[59,0,0,112],
 "interfacefstarpu__mod_1_1fstarpu__data__unregister__submit.html":[58,0,0,112],
+"interfacefstarpu__mod_1_1fstarpu__data__unregister__submit.html":[59,0,0,112],
 "interfacefstarpu__mod_1_1fstarpu__data__wont__use.html":[59,0,0,113],
 "interfacefstarpu__mod_1_1fstarpu__data__wont__use.html":[58,0,0,113],
-"interfacefstarpu__mod_1_1fstarpu__df__alloc__bcsr__filter__canonical__block.html":[59,0,0,114],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__bcsr__filter__canonical__block.html":[58,0,0,114],
+"interfacefstarpu__mod_1_1fstarpu__df__alloc__bcsr__filter__canonical__block.html":[59,0,0,114],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block.html":[59,0,0,115],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block.html":[58,0,0,115],
-"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block__shadow.html":[59,0,0,116],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block__shadow.html":[58,0,0,116],
-"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__vertical__block.html":[58,0,0,117],
+"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block__shadow.html":[59,0,0,116],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__vertical__block.html":[59,0,0,117],
-"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__vertical__block__shadow.html":[59,0,0,118],
+"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__vertical__block.html":[58,0,0,117],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__vertical__block__shadow.html":[58,0,0,118],
-"interfacefstarpu__mod_1_1fstarpu__df__alloc__csr__filter__vertical__block.html":[59,0,0,119],
+"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__vertical__block__shadow.html":[59,0,0,118],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__csr__filter__vertical__block.html":[58,0,0,119],
+"interfacefstarpu__mod_1_1fstarpu__df__alloc__csr__filter__vertical__block.html":[59,0,0,119],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__block.html":[59,0,0,120],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__block.html":[58,0,0,120],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__block__shadow.html":[59,0,0,121],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__block__shadow.html":[58,0,0,121],
-"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block.html":[59,0,0,122],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block.html":[58,0,0,122],
+"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block.html":[59,0,0,122],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block__shadow.html":[58,0,0,123],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__vertical__block__shadow.html":[59,0,0,123],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__block.html":[58,0,0,124],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__block.html":[59,0,0,124],
-"interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__block__shadow.html":[58,0,0,125],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__block__shadow.html":[59,0,0,125],
+"interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__block__shadow.html":[58,0,0,125],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__divide__in__2.html":[58,0,0,126],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__divide__in__2.html":[59,0,0,126],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__list.html":[58,0,0,127],
 "interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__list.html":[59,0,0,127],
 "interfacefstarpu__mod_1_1fstarpu__display__memory__stats.html":[58,0,0,128],
 "interfacefstarpu__mod_1_1fstarpu__display__memory__stats.html":[59,0,0,128],
-"interfacefstarpu__mod_1_1fstarpu__display__stats.html":[58,0,0,129],
 "interfacefstarpu__mod_1_1fstarpu__display__stats.html":[59,0,0,129],
-"interfacefstarpu__mod_1_1fstarpu__do__schedule.html":[58,0,0,130],
+"interfacefstarpu__mod_1_1fstarpu__display__stats.html":[58,0,0,129],
 "interfacefstarpu__mod_1_1fstarpu__do__schedule.html":[59,0,0,130],
-"interfacefstarpu__mod_1_1fstarpu__free__noflag.html":[59,0,0,131]
+"interfacefstarpu__mod_1_1fstarpu__do__schedule.html":[58,0,0,130]
 };
