@@ -77,16 +77,16 @@ var NAVTREEINDEX =
 "group__API__Codelet__And__Tasks.html#ga18bec8430309a613520d6042d701790d",
 "group__API__Data__Interfaces.html#ga0022c371e342ac366720c7735f4be3be",
 "group__API__Data__Management.html#ga5fd09305716ce9d3a5a9fd2df6bc7792",
-"group__API__Initialization__and__Termination.html#a304d0919a6a77fe0239291a4fb40d9dc",
-"group__API__MPI__Support.html#ga53f16983c6e100ed0e0e129325ddbf40",
-"group__API__OpenCL__Extensions.html#gaa38e7cb3231ed30303e50f46c8f6e39c",
-"group__API__Perf__Monitoring.html#gae9960277a9e4f22f8000ba34aa6afc42",
-"group__API__SC__Hypervisor.html#ac676ac4892a469ad4674b560c2b92514",
-"group__API__Standard__Memory__Library.html#ga4e9089680daf0b2d7f26e4657ffe9f48",
-"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37dac8fa4358a1bbed68129ebc834ee32bc1",
-"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block.html",
-"interfacefstarpu__mod_1_1fstarpu__task__get__current.html",
-"sc__hypervisor__monitoring_8h.html#ae60f91b9b83b82c3dd6ef43e7c8d730d"
+"group__API__Initialization__and__Termination.html#a2f4b44f119a585f08418771ce62321a1",
+"group__API__MPI__Support.html#ga533a908fa669cd81cfbe0323771985ad",
+"group__API__OpenCL__Extensions.html#ga9a1331f26cc54a1f5406770f68b95d29",
+"group__API__Perf__Monitoring.html#gad3e6ba0b643d9bd1a3e8920bf0b3dbea",
+"group__API__SC__Hypervisor.html#a9aba37893ddb344de680aa901f686f2d",
+"group__API__Standard__Memory__Library.html#ga49603eaea3b05e8ced9ba1bd873070c3",
+"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37da6afc9f886af7206833d473e20d2343e7",
+"interfacefstarpu__mod_1_1fstarpu__df__alloc__bcsr__filter__canonical__block.html",
+"interfacefstarpu__mod_1_1fstarpu__task__finished.html",
+"sc__hypervisor__monitoring_8h.html#adfbc9bbc2fb020e1b0c847f8557e45d6"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
