@@ -1,5 +1,6 @@
 var NAVTREEINDEX4 =
 {
+"group__API__Initialization__and__Termination.html#a2f4b44f119a585f08418771ce62321a1":[5,4,0,43],
 "group__API__Initialization__and__Termination.html#a304d0919a6a77fe0239291a4fb40d9dc":[5,4,0,47],
 "group__API__Initialization__and__Termination.html#a30cab554913e27a02512badaf204a266":[5,4,0,20],
 "group__API__Initialization__and__Termination.html#a3a4c940d048e3805784624c51cb45195":[5,4,0,25],
@@ -248,6 +249,5 @@ var NAVTREEINDEX4 =
 "group__API__MPI__Support.html#ga4799c69cb64cee04cfff4917f7cdf151":[5,27,17],
 "group__API__MPI__Support.html#ga48bd2a2569bd00cf4d1500e642015685":[5,27,89],
 "group__API__MPI__Support.html#ga4cd283c401aa59ae226bd1c5da1b295f":[5,27,108],
-"group__API__MPI__Support.html#ga5281ad23b39e64ca254347e89cbb54e2":[5,27,13],
-"group__API__MPI__Support.html#ga533a908fa669cd81cfbe0323771985ad":[5,27,82]
+"group__API__MPI__Support.html#ga5281ad23b39e64ca254347e89cbb54e2":[5,27,13]
 };
