@@ -146,15 +146,15 @@ var NAVTREEINDEX =
 "group__API__Data__Interfaces.html#aaff7aa638a24957eb76c5c40f96cddbe",
 "group__API__Data__Interfaces.html#gaf011a057a557a66271ce06e8109c11c4",
 "group__API__FFT__Support.html#gabff378384df24d2c2ea296397b600569",
-"group__API__Interop__Support.html#gad2311ec339344d00bf5afdfa0ae4077b",
-"group__API__Modularized__Scheduler.html#gaa838921844068ca3190dca5e2b5a99db",
-"group__API__Parallel__Worker.html#ga6dc4b6d66ef90b7927559c9e2728a84b",
-"group__API__Profiling.html#ga6ab0a1e4a8a55e0c54e2151fd0a82a36",
-"group__API__Scheduling__Policy.html#ga1e159d56ffa2d7705bdfd1ceb93e0d64",
-"group__API__Workers.html#ga3a6a9eddecb3e97b3c37e151003ea7c2",
-"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html",
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__min__priority.html",
-"interfacestarpu__mod_1_1starpu__asynchronous__opencl__copy__disabled.html"
+"group__API__Interop__Support.html#gad16a15386b4f7b1f8156a6b6db93db3f",
+"group__API__Modularized__Scheduler.html#ga9ed484d5707136420880285afe55bd3d",
+"group__API__Parallel__Worker.html#ga6418a1fed34b32217d66860cbf8fc200",
+"group__API__Profiling.html#ga4e4f9fb593d29219a1109062ba9d72ef",
+"group__API__Scheduling__Policy.html#ad720f2cd2155e8baa10f57792b68a5eb",
+"group__API__Workers.html#ga38c0b1858730fec2211991147a964910",
+"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html",
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__max__priority.html",
+"interfacestarpu__mod_1_1starpu__asynchronous__copy__disabled.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
