@@ -1,5 +1,7 @@
 var NAVTREEINDEX13 =
 {
+"interfacestarpu__mod_1_1starpu__asynchronous__copy__disabled.html":[12,0,2,0],
+"interfacestarpu__mod_1_1starpu__asynchronous__cuda__copy__disabled.html":[12,0,2,1],
 "interfacestarpu__mod_1_1starpu__asynchronous__opencl__copy__disabled.html":[12,0,2,2],
 "interfacestarpu__mod_1_1starpu__conf__init.html":[12,0,2,3],
 "interfacestarpu__mod_1_1starpu__cpu__worker__get__count.html":[12,0,2,4],
@@ -74,10 +76,10 @@ var NAVTREEINDEX13 =
 "starpu__bound_8h.html":[13,0,1,4],
 "starpu__bound_8h_source.html":[13,0,1,4],
 "starpu__config_8h.html":[13,0,0,0],
-"starpu__config_8h.html#a040eeaf64808762d84ff564d03090266":[13,0,0,0,11],
-"starpu__config_8h.html#a05ed4578d8a766626ad7a774483c9f5c":[13,0,0,0,28],
+"starpu__config_8h.html#a040eeaf64808762d84ff564d03090266":[13,0,0,0,12],
+"starpu__config_8h.html#a05ed4578d8a766626ad7a774483c9f5c":[13,0,0,0,29],
 "starpu__config_8h.html#a08a3c9825f3b8217c1089e97592caf80":[13,0,0,0,5],
-"starpu__config_8h.html#aa535e147c4094f10a17972c417f98d85":[13,0,0,0,27],
+"starpu__config_8h.html#aa535e147c4094f10a17972c417f98d85":[13,0,0,0,28],
 "starpu__config_8h.html#af3e493896eb70d1261709170f1a77c09":[13,0,0,0,4],
 "starpu__config_8h_source.html":[13,0,0,0],
 "starpu__cublas_8h.html":[13,0,1,5],
