@@ -1,5 +1,6 @@
 var NAVTREEINDEX5 =
 {
+"group__API__Insert__Task.html#ga4c7656d210572e4fa1860c290af2acfb":[25,13,25],
 "group__API__Insert__Task.html#ga502e5ec7928054775798a57a930bb12b":[25,13,55],
 "group__API__Insert__Task.html#ga51d0a8fa43d9289b8c9da5450faf76ad":[25,13,52],
 "group__API__Insert__Task.html#ga57022b36ea715a26133a90144265f6e1":[25,13,27],
@@ -248,6 +249,5 @@ var NAVTREEINDEX5 =
 "group__API__Max__FPGA__Extensions.html#ga6dfcf82c7b941a50a9bc2e478dfc4897":[25,17,1],
 "group__API__Max__FPGA__Extensions.html#ga7f7a92414ff1a98d7523bc40f36d0878":[25,17,2],
 "group__API__Max__FPGA__Extensions.html#gaab45e70c85fc1786d6d5e618fd5c3922":[25,17,3],
-"group__API__Max__FPGA__Extensions.html#structstarpu__max__load":[25,17,0],
-"group__API__Miscellaneous__Helpers.html":[25,36]
+"group__API__Max__FPGA__Extensions.html#structstarpu__max__load":[25,17,0]
 };
