@@ -99,16 +99,16 @@ var NAVTREEINDEX =
 "group__API__Codelet__And__Tasks.html#adac9af88fed23241fc65259712352126",
 "group__API__Data__Interfaces.html#ae1d888af673475dbcf85104b6c359a6e",
 "group__API__Data__Interfaces.html#structstarpu__variable__interface",
-"group__API__HIP__Extensions.html#gadc796fee8ebed3e8f4c12fb242f4c857",
-"group__API__MPI__Support.html#ga25408759187b030c633314855589ebcd",
-"group__API__OpenCL__Extensions.html#ga03f34ac98495afc5d0f268e366f80598",
-"group__API__Perf__Monitoring.html#ga36c44ab10f14200d43704d8771246997",
-"group__API__Running__Drivers.html#ga497d48a24107dfebf6ef3ad40d4a6df8",
-"group__API__Scheduling__Policy.html#gaa01a5b65a4c387da5f7ca711c03d41c8",
-"group__API__Workers.html#gac043c52077692456604a2f2f161b86ba",
-"interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods.html",
-"interfacefstarpu__mod_1_1fstarpu__tag__wait__array.html",
-"sc__hypervisor__monitoring_8h.html#a0cd92328373b9b5427e6bb48a44d8644"
+"group__API__HIP__Extensions.html#gad433b07789156fd12e47cf35373d36c8",
+"group__API__MPI__Support.html#ga23d04f0a7ca146314a02e4773dafde2e",
+"group__API__OpenCL__Extensions.html#a685357d9709ece920bf269a917ed8297",
+"group__API__Perf__Monitoring.html#ga247ff710854bfd7e3ab976b2ebad478e",
+"group__API__Running__Drivers.html#a50af396b52e8c54e4e3b23803105fc0e",
+"group__API__Scheduling__Policy.html#ga98ec28ae7ac484959f48b7a79372c1af",
+"group__API__Workers.html#gab568e2368c11f9fb362f04264ad4cd04",
+"interfacefstarpu__mod_1_1fstarpu__data__request__allocation.html",
+"interfacefstarpu__mod_1_1fstarpu__tag__wait.html",
+"sc__hypervisor__monitoring_8h.html#a063487ad1a8059812b5c4f721bf828f6"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
