@@ -105,16 +105,16 @@ var NAVTREEINDEX =
 "group__API__Codelet__And__Tasks.html#ad6dfcbb8bb86ca8ce0678b4b10bf853b",
 "group__API__Data__Interfaces.html#ae039cff4622424d30f99811665f4de4f",
 "group__API__Data__Interfaces.html#structstarpu__ndim__interface",
-"group__API__HIP__Extensions.html#gad40f30899d319b57afe87e9f11e873e6",
-"group__API__MPI__Support.html#ga234e28905c976ed1b03fcdf75812a06d",
-"group__API__OpenCL__Extensions.html#a685357d9709ece920bf269a917ed8297",
-"group__API__Perf__Monitoring.html#ga247ff710854bfd7e3ab976b2ebad478e",
-"group__API__Running__Drivers.html#a50af396b52e8c54e4e3b23803105fc0e",
-"group__API__Scheduling__Policy.html#ga98ec28ae7ac484959f48b7a79372c1af",
-"group__API__Workers.html#gab568e2368c11f9fb362f04264ad4cd04",
-"interfacefstarpu__mod_1_1fstarpu__data__request__allocation.html",
-"interfacefstarpu__mod_1_1fstarpu__tag__wait.html",
-"sc__hypervisor__monitoring_8h.html#a063487ad1a8059812b5c4f721bf828f6"
+"group__API__HIP__Extensions.html#gacb4a406b018e823790805c9d915dd052",
+"group__API__MPI__Support.html#ga223329eeb7c711b1b213604355981185",
+"group__API__Modularized__Scheduler.html#structstarpu__sched__tree",
+"group__API__Perf__Monitoring.html#ga15b96ecd4161e8abdea440ad89262766",
+"group__API__Running__Drivers.html",
+"group__API__Scheduling__Policy.html#ga9424eb90a56d08f804d85be6557ddf66",
+"group__API__Workers.html#gab0ffe5622c5980444226f1ed8d6fee71",
+"interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html",
+"interfacefstarpu__mod_1_1fstarpu__tag__restart.html",
+"sc__hypervisor__lp_8h_source.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
