@@ -26,7 +26,6 @@ var NAVTREE =
 [
   [ "StarPU Handbook - StarPU Introduction", "index.html", [
     [ "Introduction", "index.html", [
-      [ "we need to keep 2 blank lines above", "index.html#autotoc_md0", null ],
       [ "Motivation", "index.html#Motivation", null ],
       [ "StarPU in a Nutshell", "index.html#StarPUInANutshell", [
         [ "Codelet and Tasks", "index.html#CodeletAndTasks", null ],
@@ -74,16 +73,16 @@ var NAVTREEINDEX =
 "group__API__Codelet__And__Tasks.html#ga3c6c4dd317df02d7021e23ab6b14e3e2",
 "group__API__Data__Interfaces.html#ga11d470bd48328eb4432e1c546ea22618",
 "group__API__Data__Management.html#ga8b98dee994de7c323a81ac6e573e5693",
-"group__API__Initialization__and__Termination.html#a53d18b801302e2ccae6af09c6cdbb2c5",
-"group__API__MPI__Support.html#ga6b5f6d7fdf83ed6a9e7d7016cb67ca70",
-"group__API__OpenMP__Runtime__Support.html#a294032947604cf227abad87b30a08c27",
-"group__API__Perf__Monitoring.html#ggab66267d03f0557b14cc3ec0c24c01ebaa99c605ec09b32e1cce0ba51df5081f1d",
-"group__API__SC__Hypervisor.html#ga035e61bdee7a98948b3c7e2e0b55ef21",
-"group__API__Standard__Memory__Library.html#ga864a3b576a56d686010cfd6c9d5ef14b",
-"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a59908ef1a8ddbae47f0ff0ed704678af",
-"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block__shadow.html",
-"interfacefstarpu__mod_1_1fstarpu__task__get__implementation.html",
-"sc__hypervisor__monitoring_8h.html#aeffa224cc0e8e84dcc4decb64f2cb54c"
+"group__API__Initialization__and__Termination.html#a515df0a157b0bebc3e3aeaf6dd95bb73",
+"group__API__MPI__Support.html#ga69699989814f54defa33b444e3e59c20",
+"group__API__OpenCL__Extensions.html#structstarpu__opencl__program",
+"group__API__Perf__Monitoring.html#gga1d3b734cccfcb02c47baa5412acf0877a9ebd6023b2615a0e7e6be8e42fb0492d",
+"group__API__SC__Hypervisor.html#afdc378d28bfed82986912168bab0286b",
+"group__API__Standard__Memory__Library.html#ga84894d9a6726bca707043f484bd1a8f5",
+"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a3bb8e78a9fffd443b2e87d648a1c7531",
+"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block.html",
+"interfacefstarpu__mod_1_1fstarpu__task__get__current.html",
+"sc__hypervisor__monitoring_8h.html#aee6c9636c4ce6692556e0e87e4d16455"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
