@@ -1,5 +1,7 @@
 var NAVTREEINDEX8 =
 {
+"group__API__SC__Hypervisor.html#afdc378d28bfed82986912168bab0286b":[5,47,2,11],
+"group__API__SC__Hypervisor.html#ga022e4bef8fa4b4e68f071cbaa69c7dd5":[5,47,43],
 "group__API__SC__Hypervisor.html#ga035e61bdee7a98948b3c7e2e0b55ef21":[5,47,38],
 "group__API__SC__Hypervisor.html#ga04164c5a91df51882e8bdd84fd1b1e3f":[5,47,10],
 "group__API__SC__Hypervisor.html#ga0829a2976a7bdba7b3b5ef2124b863b2":[5,47,21],
@@ -247,7 +249,5 @@ var NAVTREEINDEX8 =
 "group__API__Standard__Memory__Library.html#ga5a6ea6d03d7b0f4a97a8046b30ecd0bb":[5,44,16],
 "group__API__Standard__Memory__Library.html#ga67c2ba763b260bea998b16881c788ae6":[5,44,5],
 "group__API__Standard__Memory__Library.html#ga6ddda4b71de54cf079a84f7c4b683443":[5,44,29],
-"group__API__Standard__Memory__Library.html#ga71ec84f082fd96f53612e684eda0e178":[5,44,26],
-"group__API__Standard__Memory__Library.html#ga84894d9a6726bca707043f484bd1a8f5":[5,44,24],
-"group__API__Standard__Memory__Library.html#ga8601b3e35b74e9cbbcefd7a9b9c6d0b8":[5,44,3]
+"group__API__Standard__Memory__Library.html#ga71ec84f082fd96f53612e684eda0e178":[5,44,26]
 };
