@@ -137,15 +137,15 @@ var NAVTREEINDEX =
 "group__API__Data__Interfaces.html#abf4cecec3e8bcec447ec51416b8ac3d2",
 "group__API__Data__Interfaces.html#gafd439524218c70b6b4a784fb12824c28",
 "group__API__FxT__Support.html#a66ac04619aec557f95ddf5a5df848341",
-"group__API__Interop__Support.html#gga33d15f419efaa08bf329d25f054fa632a40bf5a989027582689067f00115c1653",
-"group__API__Modularized__Scheduler.html#gaccfaa23c5e0948fec6be5f71fc69f32c",
-"group__API__Parallel__Worker.html#gab630219c3f24cfa1b3c096bdd19d5868",
-"group__API__Profiling.html#ga9373d4a06c86ebf9ae74b67233b8bad6",
-"group__API__Scheduling__Policy.html#ga3893905aa0eb62a541f268c6f37c491e",
-"group__API__Workers.html#ga5728fe0e4be069e45c4cd0ac0319d8a0",
-"interfacefstarpu__mod_1_1fstarpu__data__map__filters.html",
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__is__master__for__child__ctx.html",
-"interfacestarpu__mod_1_1starpu__task__wait__for__all.html"
+"group__API__Interop__Support.html#gga33d15f419efaa08bf329d25f054fa632a23e7a45ff9fdffcc8241181af2d2f14e",
+"group__API__Modularized__Scheduler.html#gac3ab95326f770ecd208a9949d18ceddf",
+"group__API__Parallel__Worker.html#ga9adce159e1660dcd3ef111816b75b04d",
+"group__API__Profiling.html#ga8dc4665fdbbbf8ce8f1b905aa8411642",
+"group__API__Scheduling__Policy.html#ga315482308105aa57ecc59e88f71823aa",
+"group__API__Workers.html#ga4998e4e1dfa0d121059c60f790496a03",
+"interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html",
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__get__id.html",
+"interfacestarpu__mod_1_1starpu__resume.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
