@@ -1,97 +1,99 @@
 var NAVTREEINDEX12 =
 {
-"interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__is__master__for__child__ctx.html":[8,0,0,216],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__get__id.html":[8,0,0,215],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__get__id.html":[9,0,0,215],
 "interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__is__master__for__child__ctx.html":[9,0,0,216],
-"interfacefstarpu__mod_1_1fstarpu__sched__get__max__priority.html":[8,0,0,217],
+"interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__is__master__for__child__ctx.html":[8,0,0,216],
 "interfacefstarpu__mod_1_1fstarpu__sched__get__max__priority.html":[9,0,0,217],
-"interfacefstarpu__mod_1_1fstarpu__sched__get__min__priority.html":[9,0,0,218],
+"interfacefstarpu__mod_1_1fstarpu__sched__get__max__priority.html":[8,0,0,217],
 "interfacefstarpu__mod_1_1fstarpu__sched__get__min__priority.html":[8,0,0,218],
-"interfacefstarpu__mod_1_1fstarpu__sched__set__max__priority.html":[9,0,0,219],
+"interfacefstarpu__mod_1_1fstarpu__sched__get__min__priority.html":[9,0,0,218],
 "interfacefstarpu__mod_1_1fstarpu__sched__set__max__priority.html":[8,0,0,219],
-"interfacefstarpu__mod_1_1fstarpu__sched__set__min__priority.html":[9,0,0,220],
+"interfacefstarpu__mod_1_1fstarpu__sched__set__max__priority.html":[9,0,0,219],
 "interfacefstarpu__mod_1_1fstarpu__sched__set__min__priority.html":[8,0,0,220],
+"interfacefstarpu__mod_1_1fstarpu__sched__set__min__priority.html":[9,0,0,220],
 "interfacefstarpu__mod_1_1fstarpu__shutdown.html":[9,0,0,221],
 "interfacefstarpu__mod_1_1fstarpu__shutdown.html":[8,0,0,221],
 "interfacefstarpu__mod_1_1fstarpu__sleep.html":[9,0,0,222],
 "interfacefstarpu__mod_1_1fstarpu__sleep.html":[8,0,0,222],
-"interfacefstarpu__mod_1_1fstarpu__tag__declare__deps__array.html":[8,0,0,223],
 "interfacefstarpu__mod_1_1fstarpu__tag__declare__deps__array.html":[9,0,0,223],
-"interfacefstarpu__mod_1_1fstarpu__tag__get__task.html":[8,0,0,224],
+"interfacefstarpu__mod_1_1fstarpu__tag__declare__deps__array.html":[8,0,0,223],
 "interfacefstarpu__mod_1_1fstarpu__tag__get__task.html":[9,0,0,224],
+"interfacefstarpu__mod_1_1fstarpu__tag__get__task.html":[8,0,0,224],
 "interfacefstarpu__mod_1_1fstarpu__tag__notify__from__apps.html":[9,0,0,225],
 "interfacefstarpu__mod_1_1fstarpu__tag__notify__from__apps.html":[8,0,0,225],
 "interfacefstarpu__mod_1_1fstarpu__tag__remove.html":[8,0,0,226],
 "interfacefstarpu__mod_1_1fstarpu__tag__remove.html":[9,0,0,226],
-"interfacefstarpu__mod_1_1fstarpu__tag__restart.html":[8,0,0,227],
 "interfacefstarpu__mod_1_1fstarpu__tag__restart.html":[9,0,0,227],
+"interfacefstarpu__mod_1_1fstarpu__tag__restart.html":[8,0,0,227],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait.html":[8,0,0,228],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait.html":[9,0,0,228],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait__array.html":[8,0,0,229],
 "interfacefstarpu__mod_1_1fstarpu__tag__wait__array.html":[9,0,0,229],
-"interfacefstarpu__mod_1_1fstarpu__task__clean.html":[9,0,0,230],
 "interfacefstarpu__mod_1_1fstarpu__task__clean.html":[8,0,0,230],
-"interfacefstarpu__mod_1_1fstarpu__task__create.html":[8,0,0,231],
+"interfacefstarpu__mod_1_1fstarpu__task__clean.html":[9,0,0,230],
 "interfacefstarpu__mod_1_1fstarpu__task__create.html":[9,0,0,231],
+"interfacefstarpu__mod_1_1fstarpu__task__create.html":[8,0,0,231],
 "interfacefstarpu__mod_1_1fstarpu__task__create__sync.html":[8,0,0,232],
 "interfacefstarpu__mod_1_1fstarpu__task__create__sync.html":[9,0,0,232],
-"interfacefstarpu__mod_1_1fstarpu__task__declare__deps.html":[9,0,0,233],
 "interfacefstarpu__mod_1_1fstarpu__task__declare__deps.html":[8,0,0,233],
+"interfacefstarpu__mod_1_1fstarpu__task__declare__deps.html":[9,0,0,233],
 "interfacefstarpu__mod_1_1fstarpu__task__declare__deps__array.html":[8,0,0,234],
 "interfacefstarpu__mod_1_1fstarpu__task__declare__deps__array.html":[9,0,0,234],
 "interfacefstarpu__mod_1_1fstarpu__task__destroy.html":[9,0,0,235],
 "interfacefstarpu__mod_1_1fstarpu__task__destroy.html":[8,0,0,235],
-"interfacefstarpu__mod_1_1fstarpu__task__dup.html":[8,0,0,236],
 "interfacefstarpu__mod_1_1fstarpu__task__dup.html":[9,0,0,236],
+"interfacefstarpu__mod_1_1fstarpu__task__dup.html":[8,0,0,236],
 "interfacefstarpu__mod_1_1fstarpu__task__end__dep__add.html":[9,0,0,237],
 "interfacefstarpu__mod_1_1fstarpu__task__end__dep__add.html":[8,0,0,237],
-"interfacefstarpu__mod_1_1fstarpu__task__end__dep__release.html":[8,0,0,238],
 "interfacefstarpu__mod_1_1fstarpu__task__end__dep__release.html":[9,0,0,238],
+"interfacefstarpu__mod_1_1fstarpu__task__end__dep__release.html":[8,0,0,238],
 "interfacefstarpu__mod_1_1fstarpu__task__finished.html":[9,0,0,239],
 "interfacefstarpu__mod_1_1fstarpu__task__finished.html":[8,0,0,239],
 "interfacefstarpu__mod_1_1fstarpu__task__get__current.html":[8,0,0,240],
 "interfacefstarpu__mod_1_1fstarpu__task__get__current.html":[9,0,0,240],
 "interfacefstarpu__mod_1_1fstarpu__task__get__implementation.html":[8,0,0,241],
 "interfacefstarpu__mod_1_1fstarpu__task__get__implementation.html":[9,0,0,241],
-"interfacefstarpu__mod_1_1fstarpu__task__init.html":[9,0,0,242],
 "interfacefstarpu__mod_1_1fstarpu__task__init.html":[8,0,0,242],
+"interfacefstarpu__mod_1_1fstarpu__task__init.html":[9,0,0,242],
 "interfacefstarpu__mod_1_1fstarpu__task__insert.html":[8,0,0,243],
 "interfacefstarpu__mod_1_1fstarpu__task__insert.html":[9,0,0,243],
 "interfacefstarpu__mod_1_1fstarpu__task__nready.html":[8,0,0,244],
 "interfacefstarpu__mod_1_1fstarpu__task__nready.html":[9,0,0,244],
-"interfacefstarpu__mod_1_1fstarpu__task__nsubmitted.html":[9,0,0,245],
 "interfacefstarpu__mod_1_1fstarpu__task__nsubmitted.html":[8,0,0,245],
-"interfacefstarpu__mod_1_1fstarpu__task__set__destroy.html":[8,0,0,246],
+"interfacefstarpu__mod_1_1fstarpu__task__nsubmitted.html":[9,0,0,245],
 "interfacefstarpu__mod_1_1fstarpu__task__set__destroy.html":[9,0,0,246],
+"interfacefstarpu__mod_1_1fstarpu__task__set__destroy.html":[8,0,0,246],
 "interfacefstarpu__mod_1_1fstarpu__task__set__implementation.html":[9,0,0,247],
 "interfacefstarpu__mod_1_1fstarpu__task__set__implementation.html":[8,0,0,247],
-"interfacefstarpu__mod_1_1fstarpu__task__submit.html":[8,0,0,248],
 "interfacefstarpu__mod_1_1fstarpu__task__submit.html":[9,0,0,248],
-"interfacefstarpu__mod_1_1fstarpu__task__submit__to__ctx.html":[8,0,0,249],
+"interfacefstarpu__mod_1_1fstarpu__task__submit.html":[8,0,0,248],
 "interfacefstarpu__mod_1_1fstarpu__task__submit__to__ctx.html":[9,0,0,249],
-"interfacefstarpu__mod_1_1fstarpu__task__wait.html":[8,0,0,250],
+"interfacefstarpu__mod_1_1fstarpu__task__submit__to__ctx.html":[8,0,0,249],
 "interfacefstarpu__mod_1_1fstarpu__task__wait.html":[9,0,0,250],
+"interfacefstarpu__mod_1_1fstarpu__task__wait.html":[8,0,0,250],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__array.html":[8,0,0,251],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__array.html":[9,0,0,251],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__all.html":[8,0,0,252],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__all.html":[9,0,0,252],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__all__in__ctx.html":[8,0,0,253],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__all__in__ctx.html":[9,0,0,253],
-"interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted.html":[8,0,0,254],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted.html":[9,0,0,254],
-"interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted__in__ctx.html":[8,0,0,255],
+"interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted.html":[8,0,0,254],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted__in__ctx.html":[9,0,0,255],
+"interfacefstarpu__mod_1_1fstarpu__task__wait__for__n__submitted__in__ctx.html":[8,0,0,255],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__no__ready.html":[8,0,0,256],
 "interfacefstarpu__mod_1_1fstarpu__task__wait__for__no__ready.html":[9,0,0,256],
-"interfacefstarpu__mod_1_1fstarpu__tensor__data__register.html":[8,0,0,257],
 "interfacefstarpu__mod_1_1fstarpu__tensor__data__register.html":[9,0,0,257],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldt.html":[8,0,0,258],
+"interfacefstarpu__mod_1_1fstarpu__tensor__data__register.html":[8,0,0,257],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldt.html":[9,0,0,258],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldy.html":[9,0,0,259],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldt.html":[8,0,0,258],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldy.html":[8,0,0,259],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__ldy.html":[9,0,0,259],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldz.html":[9,0,0,260],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ldz.html":[8,0,0,260],
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__nt.html":[8,0,0,261],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nt.html":[9,0,0,261],
+"interfacefstarpu__mod_1_1fstarpu__tensor__get__nt.html":[8,0,0,261],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nx.html":[9,0,0,262],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__nx.html":[8,0,0,262],
 "interfacefstarpu__mod_1_1fstarpu__tensor__get__ny.html":[9,0,0,263],
@@ -108,68 +110,68 @@ var NAVTREEINDEX12 =
 "interfacefstarpu__mod_1_1fstarpu__topology__print.html":[9,0,0,268],
 "interfacefstarpu__mod_1_1fstarpu__trace__user__event.html":[8,0,0,269],
 "interfacefstarpu__mod_1_1fstarpu__trace__user__event.html":[9,0,0,269],
-"interfacefstarpu__mod_1_1fstarpu__unpack__arg.html":[8,0,0,270],
 "interfacefstarpu__mod_1_1fstarpu__unpack__arg.html":[9,0,0,270],
-"interfacefstarpu__mod_1_1fstarpu__usleep.html":[9,0,0,271],
+"interfacefstarpu__mod_1_1fstarpu__unpack__arg.html":[8,0,0,270],
 "interfacefstarpu__mod_1_1fstarpu__usleep.html":[8,0,0,271],
-"interfacefstarpu__mod_1_1fstarpu__variable__data__register.html":[9,0,0,272],
+"interfacefstarpu__mod_1_1fstarpu__usleep.html":[9,0,0,271],
 "interfacefstarpu__mod_1_1fstarpu__variable__data__register.html":[8,0,0,272],
-"interfacefstarpu__mod_1_1fstarpu__variable__get__ptr.html":[8,0,0,273],
+"interfacefstarpu__mod_1_1fstarpu__variable__data__register.html":[9,0,0,272],
 "interfacefstarpu__mod_1_1fstarpu__variable__get__ptr.html":[9,0,0,273],
-"interfacefstarpu__mod_1_1fstarpu__variable__ptr__register.html":[8,0,0,274],
+"interfacefstarpu__mod_1_1fstarpu__variable__get__ptr.html":[8,0,0,273],
 "interfacefstarpu__mod_1_1fstarpu__variable__ptr__register.html":[9,0,0,274],
-"interfacefstarpu__mod_1_1fstarpu__vector__data__register.html":[8,0,0,275],
+"interfacefstarpu__mod_1_1fstarpu__variable__ptr__register.html":[8,0,0,274],
 "interfacefstarpu__mod_1_1fstarpu__vector__data__register.html":[9,0,0,275],
-"interfacefstarpu__mod_1_1fstarpu__vector__divide__in__2.html":[8,0,0,276],
+"interfacefstarpu__mod_1_1fstarpu__vector__data__register.html":[8,0,0,275],
 "interfacefstarpu__mod_1_1fstarpu__vector__divide__in__2.html":[9,0,0,276],
-"interfacefstarpu__mod_1_1fstarpu__vector__filter__block.html":[8,0,0,277],
+"interfacefstarpu__mod_1_1fstarpu__vector__divide__in__2.html":[8,0,0,276],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__block.html":[9,0,0,277],
-"interfacefstarpu__mod_1_1fstarpu__vector__filter__block__shadow.html":[9,0,0,278],
+"interfacefstarpu__mod_1_1fstarpu__vector__filter__block.html":[8,0,0,277],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__block__shadow.html":[8,0,0,278],
+"interfacefstarpu__mod_1_1fstarpu__vector__filter__block__shadow.html":[9,0,0,278],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__list.html":[8,0,0,279],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__list.html":[9,0,0,279],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__list__long.html":[8,0,0,280],
 "interfacefstarpu__mod_1_1fstarpu__vector__filter__list__long.html":[9,0,0,280],
-"interfacefstarpu__mod_1_1fstarpu__vector__get__nx.html":[8,0,0,281],
 "interfacefstarpu__mod_1_1fstarpu__vector__get__nx.html":[9,0,0,281],
-"interfacefstarpu__mod_1_1fstarpu__vector__get__ptr.html":[8,0,0,282],
+"interfacefstarpu__mod_1_1fstarpu__vector__get__nx.html":[8,0,0,281],
 "interfacefstarpu__mod_1_1fstarpu__vector__get__ptr.html":[9,0,0,282],
+"interfacefstarpu__mod_1_1fstarpu__vector__get__ptr.html":[8,0,0,282],
 "interfacefstarpu__mod_1_1fstarpu__vector__ptr__register.html":[8,0,0,283],
 "interfacefstarpu__mod_1_1fstarpu__vector__ptr__register.html":[9,0,0,283],
-"interfacefstarpu__mod_1_1fstarpu__void__data__register.html":[8,0,0,284],
 "interfacefstarpu__mod_1_1fstarpu__void__data__register.html":[9,0,0,284],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html":[8,0,0,285],
+"interfacefstarpu__mod_1_1fstarpu__void__data__register.html":[8,0,0,284],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html":[9,0,0,285],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[9,0,0,286],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html":[8,0,0,285],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[8,0,0,286],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[9,0,0,286],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[9,0,0,287],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[8,0,0,287],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[8,0,0,288],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[9,0,0,288],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[9,0,0,289],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[8,0,0,288],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[8,0,0,289],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[9,0,0,290],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[9,0,0,289],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[8,0,0,290],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[9,0,0,291],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[9,0,0,290],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[8,0,0,291],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[9,0,0,292],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[9,0,0,291],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[8,0,0,292],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[9,0,0,293],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[9,0,0,292],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[8,0,0,293],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[9,0,0,294],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[9,0,0,293],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[8,0,0,294],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[9,0,0,295],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[9,0,0,294],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[8,0,0,295],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[9,0,0,295],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__type__as__string.html":[9,0,0,296],
 "interfacefstarpu__mod_1_1fstarpu__worker__get__type__as__string.html":[8,0,0,296],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__blocked.html":[8,0,0,297],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__blocked.html":[9,0,0,297],
-"interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[8,0,0,298],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[9,0,0,298],
-"interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[8,0,0,299],
+"interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[8,0,0,298],
 "interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[9,0,0,299],
-"interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html":[8,0,0,300],
+"interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[8,0,0,299],
 "interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html":[9,0,0,300],
+"interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html":[8,0,0,300],
 "interfacefstarpu__mpi__mod_1_1fstarpu__mpi__barrier.html":[9,0,1,0],
 "interfacefstarpu__mpi__mod_1_1fstarpu__mpi__cache__flush.html":[9,0,1,1],
 "interfacefstarpu__mpi__mod_1_1fstarpu__mpi__cache__flush__all__data.html":[9,0,1,2],
@@ -247,7 +249,5 @@ var NAVTREEINDEX12 =
 "interfacestarpu__mod_1_1starpu__display__stats.html":[9,0,2,5],
 "interfacestarpu__mod_1_1starpu__get__version.html":[9,0,2,6],
 "interfacestarpu__mod_1_1starpu__init.html":[9,0,2,7],
-"interfacestarpu__mod_1_1starpu__pause.html":[9,0,2,8],
-"interfacestarpu__mod_1_1starpu__resume.html":[9,0,2,9],
-"interfacestarpu__mod_1_1starpu__shutdown.html":[9,0,2,10]
+"interfacestarpu__mod_1_1starpu__pause.html":[9,0,2,8]
 };
