@@ -1,5 +1,7 @@
 var NAVTREEINDEX9 =
 {
+"group__API__Scheduling__Policy.html#ga315482308105aa57ecc59e88f71823aa":[7,24,42],
+"group__API__Scheduling__Policy.html#ga318f5a51b8f948940c754df6962be263":[7,24,35],
 "group__API__Scheduling__Policy.html#ga3893905aa0eb62a541f268c6f37c491e":[7,24,44],
 "group__API__Scheduling__Policy.html#ga39d52be64d37a80809f256c749fd37ca":[7,24,32],
 "group__API__Scheduling__Policy.html#ga3aa31bfaf64f1281d2da89eac0dba84d":[7,24,5],
@@ -247,7 +249,5 @@ var NAVTREEINDEX9 =
 "group__API__Workers.html#ga3fa9784ddcf3fc9f496e33fe4cad54ce":[7,18,38],
 "group__API__Workers.html#ga40eea17cbbabcb0eed906d0b50604ed2":[7,18,63],
 "group__API__Workers.html#ga45611e9799d1c32e826c5f2f6a642c65":[7,18,51],
-"group__API__Workers.html#ga479f8ed78324dca80ad746d0fee5d832":[7,18,7],
-"group__API__Workers.html#ga4998e4e1dfa0d121059c60f790496a03":[7,18,24],
-"group__API__Workers.html#ga53bac558c693f8cfdeef94bc6b64ab0b":[7,18,53]
+"group__API__Workers.html#ga479f8ed78324dca80ad746d0fee5d832":[7,18,7]
 };
