@@ -1,46 +1,48 @@
 var NAVTREEINDEX6 =
 {
-"group__API__Modularized__Scheduler.html#ga70c74dee688684fb09e45833094ba21a":[6,22,26],
+"group__API__Modularized__Scheduler.html#ga699b31664bb3665f25ef360c2512d8f9":[6,22,59],
+"group__API__Modularized__Scheduler.html#ga6b1f65158357aae0d9239063e54f82a4":[6,22,21],
+"group__API__Modularized__Scheduler.html#ga70c74dee688684fb09e45833094ba21a":[6,22,27],
 "group__API__Modularized__Scheduler.html#ga72554d14205573f57631b850afa3f39f":[6,22,11],
-"group__API__Modularized__Scheduler.html#ga752889050651f6e3c83ddd2c3f96c0ff":[6,22,63],
-"group__API__Modularized__Scheduler.html#ga782b27a1b864b0d21294f3d8da8756f8":[6,22,60],
-"group__API__Modularized__Scheduler.html#ga79594b4403678fa1d6aa08f7fbe6e525":[6,22,44],
-"group__API__Modularized__Scheduler.html#ga795d692f797ef022c350c9b5922cec31":[6,22,40],
+"group__API__Modularized__Scheduler.html#ga752889050651f6e3c83ddd2c3f96c0ff":[6,22,64],
+"group__API__Modularized__Scheduler.html#ga782b27a1b864b0d21294f3d8da8756f8":[6,22,61],
+"group__API__Modularized__Scheduler.html#ga79594b4403678fa1d6aa08f7fbe6e525":[6,22,45],
+"group__API__Modularized__Scheduler.html#ga795d692f797ef022c350c9b5922cec31":[6,22,41],
 "group__API__Modularized__Scheduler.html#ga7bacda898bdd7964b21ce611c7db077b":[6,22,10],
-"group__API__Modularized__Scheduler.html#ga7ceaaeea8cc10f6d67706c4ee33e93ce":[6,22,36],
-"group__API__Modularized__Scheduler.html#ga813c6be6ae07ec5fe6e54a1bd97267ce":[6,22,21],
-"group__API__Modularized__Scheduler.html#ga862bc72530533cc7eab28294676f5318":[6,22,55],
-"group__API__Modularized__Scheduler.html#ga87785b9c9eeb3718d85dc1b2a24fab26":[6,22,28],
-"group__API__Modularized__Scheduler.html#ga8efad6df3a5b036619ea5c76fe50a0c5":[6,22,51],
-"group__API__Modularized__Scheduler.html#ga90dfe435a72d46bd23ddaffa287833c2":[6,22,39],
+"group__API__Modularized__Scheduler.html#ga7ceaaeea8cc10f6d67706c4ee33e93ce":[6,22,37],
+"group__API__Modularized__Scheduler.html#ga813c6be6ae07ec5fe6e54a1bd97267ce":[6,22,22],
+"group__API__Modularized__Scheduler.html#ga862bc72530533cc7eab28294676f5318":[6,22,56],
+"group__API__Modularized__Scheduler.html#ga87785b9c9eeb3718d85dc1b2a24fab26":[6,22,29],
+"group__API__Modularized__Scheduler.html#ga8efad6df3a5b036619ea5c76fe50a0c5":[6,22,52],
+"group__API__Modularized__Scheduler.html#ga90dfe435a72d46bd23ddaffa287833c2":[6,22,40],
 "group__API__Modularized__Scheduler.html#ga966aaa040948551bede3ee46c9f8847e":[6,22,18],
-"group__API__Modularized__Scheduler.html#ga9bfbf9eb07c5ccc7c77a40ddb37056b8":[6,22,67],
-"group__API__Modularized__Scheduler.html#ga9ed484d5707136420880285afe55bd3d":[6,22,43],
-"group__API__Modularized__Scheduler.html#gaa207453a69f029b2f3c74bc8b9cffde2":[6,22,69],
+"group__API__Modularized__Scheduler.html#ga9bfbf9eb07c5ccc7c77a40ddb37056b8":[6,22,68],
+"group__API__Modularized__Scheduler.html#ga9ed484d5707136420880285afe55bd3d":[6,22,44],
+"group__API__Modularized__Scheduler.html#gaa207453a69f029b2f3c74bc8b9cffde2":[6,22,70],
 "group__API__Modularized__Scheduler.html#gaa838921844068ca3190dca5e2b5a99db":[6,22,13],
-"group__API__Modularized__Scheduler.html#gaab8471a2921b0508b9269b08ecfba3b7":[6,22,42],
-"group__API__Modularized__Scheduler.html#gab17420484cfb68122d986d1feee91905":[6,22,76],
-"group__API__Modularized__Scheduler.html#gab40975877d0c861348ccc96602be2cae":[6,22,25],
-"group__API__Modularized__Scheduler.html#gab8540c0e69c3af17c424944af9b3c802":[6,22,27],
+"group__API__Modularized__Scheduler.html#gaab8471a2921b0508b9269b08ecfba3b7":[6,22,43],
+"group__API__Modularized__Scheduler.html#gab17420484cfb68122d986d1feee91905":[6,22,77],
+"group__API__Modularized__Scheduler.html#gab40975877d0c861348ccc96602be2cae":[6,22,26],
+"group__API__Modularized__Scheduler.html#gab8540c0e69c3af17c424944af9b3c802":[6,22,28],
 "group__API__Modularized__Scheduler.html#gabd7a0274979659050496fcc1c66b7a1c":[6,22,8],
-"group__API__Modularized__Scheduler.html#gabf51817bd8f2a32af327d90eb5d126ec":[6,22,54],
-"group__API__Modularized__Scheduler.html#gac3ab95326f770ecd208a9949d18ceddf":[6,22,65],
-"group__API__Modularized__Scheduler.html#gac863df9e289543dcfd6a0b5e4e60432a":[6,22,22],
-"group__API__Modularized__Scheduler.html#gaccfaa23c5e0948fec6be5f71fc69f32c":[6,22,73],
-"group__API__Modularized__Scheduler.html#gad06fa143512ae761c452bf0adf685bae":[6,22,53],
+"group__API__Modularized__Scheduler.html#gabf51817bd8f2a32af327d90eb5d126ec":[6,22,55],
+"group__API__Modularized__Scheduler.html#gac3ab95326f770ecd208a9949d18ceddf":[6,22,66],
+"group__API__Modularized__Scheduler.html#gac863df9e289543dcfd6a0b5e4e60432a":[6,22,23],
+"group__API__Modularized__Scheduler.html#gaccfaa23c5e0948fec6be5f71fc69f32c":[6,22,74],
+"group__API__Modularized__Scheduler.html#gad06fa143512ae761c452bf0adf685bae":[6,22,54],
 "group__API__Modularized__Scheduler.html#gad0e17cdc3def6bd7e9a9a17437969bdb":[6,22,19],
-"group__API__Modularized__Scheduler.html#gad76ac70069357b5a3d0ac0a1489016a2":[6,22,68],
+"group__API__Modularized__Scheduler.html#gad76ac70069357b5a3d0ac0a1489016a2":[6,22,69],
 "group__API__Modularized__Scheduler.html#gae1aa931285a2b952473fc7def121c5cd":[6,22,16],
-"group__API__Modularized__Scheduler.html#gae1ac4bb35944de31705ba297aef1f9a1":[6,22,49],
+"group__API__Modularized__Scheduler.html#gae1ac4bb35944de31705ba297aef1f9a1":[6,22,50],
 "group__API__Modularized__Scheduler.html#gae4532cd31d9d069b810bdf52db2e052e":[6,22,15],
 "group__API__Modularized__Scheduler.html#gae4fc13eee5dd3528951a5cfea33c03ce":[6,22,12],
-"group__API__Modularized__Scheduler.html#gae97d6b25d8143ef2f7b6260c6f550c5c":[6,22,31],
-"group__API__Modularized__Scheduler.html#gaec7ff28a32f69a93850a1233a1c2725f":[6,22,34],
+"group__API__Modularized__Scheduler.html#gae97d6b25d8143ef2f7b6260c6f550c5c":[6,22,32],
+"group__API__Modularized__Scheduler.html#gaec7ff28a32f69a93850a1233a1c2725f":[6,22,35],
 "group__API__Modularized__Scheduler.html#gafb485fe5fb1f46c7ce7eb505815f306b":[6,22,9],
 "group__API__Modularized__Scheduler.html#gafb5ce04aff2175aed3763a72bf252107":[6,22,20],
-"group__API__Modularized__Scheduler.html#gafb683e254b5084a1321a21fde5139b01":[6,22,52],
-"group__API__Modularized__Scheduler.html#ggab40975877d0c861348ccc96602be2caea27934b03d9ff6827b318124ff683fb40":[6,22,25,0],
-"group__API__Modularized__Scheduler.html#ggab40975877d0c861348ccc96602be2caea40dba09874d6d3a220669e0ccea27da2":[6,22,25,1],
+"group__API__Modularized__Scheduler.html#gafb683e254b5084a1321a21fde5139b01":[6,22,53],
+"group__API__Modularized__Scheduler.html#ggab40975877d0c861348ccc96602be2caea27934b03d9ff6827b318124ff683fb40":[6,22,26,0],
+"group__API__Modularized__Scheduler.html#ggab40975877d0c861348ccc96602be2caea40dba09874d6d3a220669e0ccea27da2":[6,22,26,1],
 "group__API__Modularized__Scheduler.html#structstarpu__sched__component":[6,22,0],
 "group__API__Modularized__Scheduler.html#structstarpu__sched__component__fifo__data":[6,22,2],
 "group__API__Modularized__Scheduler.html#structstarpu__sched__component__heteroprio__data":[6,22,5],
@@ -247,7 +249,5 @@ var NAVTREEINDEX6 =
 "group__API__Parallel__Tasks.html#ga5b81d2b58b724e33b7fcbb546464510a":[6,19,1],
 "group__API__Parallel__Tasks.html#ga720a70f5297ffe3b5ea5cf6eff549c8c":[6,19,6],
 "group__API__Parallel__Tasks.html#gae3fe82c940e36715145baa9fe003e453":[6,19,7],
-"group__API__Parallel__Tasks.html#gae53499613fb72e9aa1abad6437a926f9":[6,19,2],
-"group__API__Parallel__Tasks.html#gaf99bc08bf6f586b658febdd1dc6fef80":[6,19,9],
-"group__API__Parallel__Worker.html":[6,37]
+"group__API__Parallel__Tasks.html#gae53499613fb72e9aa1abad6437a926f9":[6,19,2]
 };
