@@ -1,5 +1,7 @@
 var NAVTREEINDEX7 =
 {
+"group__API__Parallel__Tasks.html#gaf99bc08bf6f586b658febdd1dc6fef80":[6,19,9],
+"group__API__Parallel__Worker.html":[6,37],
 "group__API__Parallel__Worker.html#ga01d8f8727b395aa7b49b77772b43f215":[6,37,1],
 "group__API__Parallel__Worker.html#ga0b55812dec189a94c1e54c06482336b9":[6,37,3],
 "group__API__Parallel__Worker.html#ga0b8011473a2abad180217861366c5a19":[6,37,20],
@@ -247,7 +249,5 @@ var NAVTREEINDEX7 =
 "group__API__Profiling.html#a650860076a4d4c07929e97ec64386724":[6,40,0,2],
 "group__API__Profiling.html#a67bee4aeadbec19556780f8328110957":[6,40,1,7],
 "group__API__Profiling.html#a6e85ac77428f572c5380e283b943459c":[6,40,0,16],
-"group__API__Profiling.html#a73a1303e033dffe94ff162e8e21122d1":[6,40,1,12],
-"group__API__Profiling.html#a78e32404bdff71292562d2dc5892061c":[6,40,0,15],
-"group__API__Profiling.html#a8032d6b4c3391555b255718d7da4279c":[6,40,2,0]
+"group__API__Profiling.html#a73a1303e033dffe94ff162e8e21122d1":[6,40,1,12]
 };
